Development
===========


Development install
-------------------
Users interested in developing can install the latest version from `github <https://github.com/strawpants/xinv/tree/main>`_. Cython is needed in case the binary extension is being developed, and users can consult the dedicated instructions on the github repository.




Testing suite with pytest
-------------------------
From the repositories root directory, the entire test suite can be run with the following command:

.. code-block:: console

   python -m pytest tests/


Coding style
------------
Code can be supplied with `numpy docstrings <https://www.sphinx-doc.org/en/master/usage/extensions/example_numpy.html>`_ so they can be parsed into this documentation.
